{{extend defaultLayout}} {{block 'css'}}
<script src="{{_res_path}}template/extend/js/qrcode.min.js"></script>
<link rel="stylesheet" type="text/css" href="{{_res_path}}template/bilibili/css/dynamic/base.css" />
{{/block}} {{block 'main'}}

<div class="spacer2"></div>
<div class="bitop">
  <img src="{{_res_path}}image/bilibili/bilibili.png" alt="bilibili" />
  &nbsp;&nbsp;&nbsp;&nbsp;
  <span style="font-size: 50px">你感兴趣的视频都在哔哩哔哩</span>
</div>
<div class="spacer2"></div>
{{each image_url val}}
<div class="cover">
  <div class="imgbox">
    <img class="imgbox_1" src="{{val.image_src}}" alt="封面" />
  </div>
</div>
<div style="height: 20px"></div>
{{/each}}
<div class="info">
  <div class="info_text">{{@text}}</div>
  <div class="spacer4"></div>
  <div class="work_status">{{dianzan}}点赞 · {{pinglun}}评论 · {{share}}分享</div>
  <div class="spacer5"></div>
  <div class="dynamic_create_time">发布于{{create_time}}</div>
</div>
<div class="spacer6"></div>
<div class="other_text">哔哩哔哩{{dynamicTYPE}}</div>
<div class="under">
  <div class="rectangular_box">
    <div class="user" style="align-items: center; padding: 0 0 0 50px">
      <div class="userinfo">
        <div><img src="{{avatar_url}}" alt="头像" class="avatar" /></div>
        <img src="{{frame}}" class="avatar-1" />
        <div class="name_and_followers">
          <div class="username"><span>{{@username}}</span></div>
        </div>
      </div>
      <div class="userinfo_text">
        <span>UID: {{user_shortid}}</span>
        <span>获赞: {{total_favorited}}</span>
        <span>关注: {{following_count}}</span>
        <span>粉丝: {{fans}}</span>
      </div>
    </div>
    <div class="qrcode_box">
      <div class="qrcode_text">动态分享链接</div>
      <div id="qrcode"></div>
    </div>
  </div>
</div>
<script>
  qrcode = new QRCode(document.getElementById('qrcode'), {
    width: 600,
    height: 600,
    colorDark: '{{useDarkTheme}}' === 'true' ? '#c3c3c3' : '#3a3a3a',
    colorLight: '{{useDarkTheme}}' === 'true' ? '#121212' : '#f4f4f4',
  })
  qrcode.makeCode('{{share_url}}')
</script>
{{/block}}