<!doctype html>
<html>

<head>
  <title>text</title>
  <meta charset="utf-8" />
  <meta name="viewport" content="width=device-width, initial-scale=1.0" />
  <link rel="stylesheet" type="text/css" href="{{_res_path}}template/bilibili/css/bangumi.css" />

  <!-- The content below will be included at the end of the <head> element. -->
  <script type="text/javascript">
    document.addEventListener('DOMContentLoaded', function () {
      // your code here
    })
  </script>
</head>

<body for="html-export">
  <div class="crossnote markdown-preview">
    <h1>{{title}}</h1>
    <hr />
    <blockquote>
      {{each bangumiData val}}
      <div>
        <h3>第 {{val.id}} 集</h3>
        <p>
          <br />
          标题: {{val.long_title}}
          <br />
          🔒 播放要求: {{if val.badge === '会员'}}
          <span style="color: #fb7299; font-weight: 700">{{val.badge}}</span>
          {{else}}
          <strong>{{val.badge}}</strong>
          {{/if}}
          <br />
          🔗 分享链接:
          <a href="{{val.short_link}}">{{val.short_link}}</a>
        </p>
      </div>
      {{/each}}
    </blockquote>
    <hr />
    <p>
      输入
      <strong>第?集</strong>
      进行选集
      <br />
      <s>温馨提示:</s>
      你有 60 秒的时间进行选择
    </p>
  </div>
</body>

</html>