body.light-mode .container {
  position: relative;
  background-color: #f4f4f4;
  width: 1440px;
  height: auto;
}

body.dark-mode .container {
  position: relative;
  background-color: #1A1A1A;
  width: 1440px;
  height: auto;
}

.spacer1 {
  height: 60px;
}

.spacer2 {
  height: 82px;
}

.spacer3 {
  height: 50px;
}

.spacer4 {
  height: 60px;
}

.spacer5 {
  height: 10px;
}

.spacer6 {
  height: 100px;
}

.container {
  width: 100% !important;
  margin: 0 auto;
}

body.light-mode .bitop {
  color: #3e3e3eb8;
  font-size: 65px;
  display: -moz-box;
  display: -ms-flexbox;
  -moz-box-align: center;
  -ms-flex-align: center;
  align-items: center;
}

body.dark-mode .bitop {
  color: #d3d3d3;
  font-size: 65px;
  display: -moz-box;
  display: -ms-flexbox;
  -moz-box-align: center;
  -ms-flex-align: center;
  align-items: center;
}

.bitop img {
  width: 320px;
  height: auto;
}

.AVcover {
  display: flex;
  flex-direction: column;
  align-items: center;
  padding: 45px 0 25px 0;
}

body.light-mode .imgbox {
  display: flex;
  flex-direction: column;
  align-items: center;
  box-shadow: 0px 10px 20px 0px #a5a5a5;
  border-radius: 40px;
  width: 95%;
  aspect-ratio: 16 / 9;
  overflow: hidden;
  position: relative;
}

body.dark-mode .imgbox {
  display: flex;
  flex-direction: column;
  align-items: center;
  box-shadow: 0px 10px 30px 10px #0f0f0f;
  border-radius: 25px;
  width: 95%;
  aspect-ratio: 16 / 9;
  overflow: hidden;
  position: relative;
}

.imgbox_1 {
  position: absolute;
  width: 100%;
  height: 125%;
  object-fit: cover;
  object-position: center 200%;
}

.gradient-overlay {
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  height: 50%;
  background: linear-gradient(to top, #000000bd 0%, #00000000 100%);
  pointer-events: none;
}

.image-text {
  position: absolute;
  bottom: 32px;
  left: 50px;
  right: 20px;
  color: white;
  font-size: 37px;
  font-weight: 300;
  text-shadow: 1px 1px 3px #00000099;
  z-index: 1;
}

.duration_text {
  padding: 10px 15px;
  font-size: 35px;
  color: #ffffff;
  text-shadow: 0px 0px 10px #ffffff;
  background-color: #00000078;
  border-radius: 10px;
}

.info {
  width: 100% !important;
  display: flex !important;
  flex-direction: column;
  padding: 0 85px !important;
  line-height: 1.5;
}

body.light-mode .info_text {
  font-size: 65px;
  align-items: center;
  letter-spacing: 1.5px;
  position: relative;
  word-wrap: break-word;
}

body.dark-mode .info_text {
  font-size: 65px;
  align-items: center;
  letter-spacing: 1.5px;
  position: relative;
  word-wrap: break-word;
  color: #e9e9e9;
}

body.light-mode .forward_info_text {
  font-size: 50px;
  align-items: center;
  letter-spacing: 1.5px;
  position: relative;
  word-wrap: break-word;
  line-height: 1.5;
}

body.dark-mode .forward_info_text {
  font-size: 50px;
  align-items: center;
  letter-spacing: 1.5px;
  position: relative;
  word-wrap: break-word;
  color: #e9e9e9;
  line-height: 1.5;
}

body.light-mode .video_info_text {
  font-size: 80px;
  font-weight: 700;
  align-items: center;
  letter-spacing: 1.5px;
  position: relative;
  word-wrap: break-word;
}


body.dark-mode .DYNAMIC_TYPE_AV.user.name {
  font-size: 40px;
  align-items: center;
  letter-spacing: 1.5px;
  color: #e7e7e7;
}

body.light-mode .DYNAMIC_TYPE_AV {
  background-color: #efefef;
  border-radius: 20px;
  margin-top: 14px;
  padding: 30px 50px 35px 50px;
  width: 100%;
}

body.dark-mode .DYNAMIC_TYPE_AV {
  background-color: #282828;
  border-radius: 15px;
  margin-top: 14px;
  padding: 20px;
  width: 100%;
}


.AVuserinfo {
  display: flex;
  align-items: center;
  padding: 25px 0 0 35px;
}

.AV.avatar {
  margin: 0px 20px 0 0;
  border-radius: 50%;
  height: auto;
  width: 100px;
  box-shadow: 0px 10px 20px 0px #4343434f;
}

.name {
  font-size: 55px;
  color: #dedede;
  /* margin: 0 0 0 20px; */
}

body.light-mode .intro {
  color: #2f2f2f;
  font-size: 65px;
  font-weight: 700;
  padding-left: 30px;
}

body.dark-mode .intro {
  color: #e9e9e9;
  font-size: 60px;
  font-weight: 700;
  padding-left: 30px;
}

.work_status {
  color: #808080;
  letter-spacing: normal;
  font-size: 45px;
  font-weight: 300;
}

.dynamic_create_time {
  white-space: nowrap;
  color: #808080;
  font-size: 35px;
  font-weight: 400;
}

.under {
  display: flex;
  height: 100%;
  flex-direction: column;
}

.rectangular_box {
  height: auto;
  display: -webkit-box;
  display: -webkit-flex;
  display: -moz-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-pack: justify;
  -webkit-justify-content: space-between;
  -moz-box-pack: justify;
  -ms-flex-pack: justify;
  justify-content: space-between;
  padding: 100px 0 45px 0;
  -webkit-box-align: center;
  -webkit-align-items: center;
  -moz-box-align: center;
  -ms-flex-align: center;
  align-items: center;
}

.user {
  display: flex;
  flex-direction: column;
  padding-left: 65px;
}

.userinfo {
  display: flex;
  align-items: center;
  padding: 0 0 0 100px;
}

body.light-mode .userinfo_text {
  display: flex;
  font-size: 35px;
  color: #2f2f2f;
  padding: 25px 0 0 0;
  flex-direction: column;
  align-items: flex-start;
  width: 100%;
  letter-spacing: 2.5px;
}

body.dark-mode .userinfo_text {
  display: flex;
  font-size: 35px;
  color: #cfcfcf;
  padding: 25px 0 0 0;
  flex-direction: column;
  align-items: flex-start;
  width: 100%;
  letter-spacing: 2.5px;
}

.name_and_followers {
  display: flex;
  font-size: 30px;
  flex-direction: column;
}

.bili_dyn_item_ornament {
  padding: 0 0 0 235px;
}

.name_and_followers_text {
  font-size: 20px;
  color: #2f2f2f;
  margin-left: 10px;
  text-align: right;
  margin-right: 10px;
}

.avatar {
  margin: 0px 20px 0 0;
  border-radius: 50%;
  height: auto;
  width: 145px;
  box-shadow: 0px 10px 20px 0px #4343434f;
}

.avatar-1 {
  width: 142px;
  /* height: 150px; */
  margin: 0 -115px 0 0;
  margin-top: 50px;
  transform: translateY(-17%) translateX(-115%) scale(1.8);
}

/* Ã¥Â½â€œimgÃ¥â€¦Æ’Ã§Â´Â Ã¤Â¸ÂºÃ§Â©ÂºÃ¦â€”Â¶Ã¯Â¼Å’Ã¨Â®Â¾Ã§Â½Â®Ã¥â€¦Æ’Ã§Â´Â Ã©â‚¬ÂÃ¦ËœÅ½Ã¥ÂºÂ¦Ã¤Â¸Âº0Ã¯Â¼Å’Ã¥â€ºÂ¾Ã¨Â£â€šÃ¥â€ºÂ¾Ã¦Â â€¡Ã¥Â°â€ Ã¨Â¢Â«Ã©Å¡ÂÃ¨â€”Â */
img[src=''],
img:not([src]) {
  opacity: 0;
}

.username {
  font-weight: 700;
  font-size: 60px;
  /* margin: 0 0 0 0; */
}

.qrcode_box {
  display: flex !important;
  margin: 0 75px -50px 0 !important;
  align-items: center !important;
  flex-direction: column-reverse;
}

body.light-mode .qrcode_text {
  font-size: 45px;
  color: #2f2f2f;
  margin-left: 10px;
  text-align: right;
  margin: 20px 0 0 0;
}

body.dark-mode .qrcode_text {
  font-size: 45px;
  color: #d7d7d7;
  margin-left: 10px;
  text-align: right;
  margin: 20px 0 0 0;
}

body.light-mode #qrcode {
  border: 7px dashed #3a3a3a;
  padding: 10px;
  border-radius: 2%;
}

body.dark-mode #qrcode {
  border: 7px dashed #C3C3C3;
  padding: 10px;
  border-radius: 2%;
}

#qrcode img {
  width: 350px;
  height: auto;
}

body.light-mode .other_text {
  color: #575757;
  font-size: 70px;
  text-align: right;
  margin: 0 80px -45px 0;
  z-index: -1;
}

body.dark-mode .other_text {
  color: #c1c1c1;
  font-size: 70px;
  text-align: right;
  margin: 0 80px -45px 0;
  z-index: -1;
}


.original-content {
  display: flex;
  width: 92%;
  padding: 0 0 0 85px;
}

body.dark-mode .DYNAMIC_TYPE_DRAW {
  background-color: #282828;
  border-radius: 20px;
  margin-top: 14px;
  padding: 30px 50px 0 50px;
  width: 100%;
}

body.light-mode .DYNAMIC_TYPE_DRAW {
  background-color: #efefef;
  border-radius: 20px;
  margin-top: 14px;
  padding: 30px 50px 0 50px;
  width: 100%;
}

body.dark-mode .DYNAMIC_TYPE_WORD {
  background-color: #282828;
  border-radius: 20px;
  margin-top: 14px;
  padding: 30px 50px 70px 50px;
  width: 100%;
}

body.light-mode .DYNAMIC_TYPE_WORD {
  background-color: #efefef;
  border-radius: 20px;
  margin-top: 14px;
  padding: 30px 50px 70px 50px;
  width: 100%;
}

.DRAWuserinfo {
  display: flex;
  padding: 25px 0 0 0;
  align-items: center;
}

.forward_avatar {
  margin: 0px 50px 0 0;
  border-radius: 50%;
  height: 125px;
  width: auto;
  box-shadow: 0px 10px 20px 0px #4343434f;
}

/* Ã¥Ââ€¢Ã¥â€ºÂ¾Ã¦Â Â·Ã¥Â¼Â */
.single-image-container {
  max-width: 100%;
  margin: 0 auto;
}

.DRAWcover {
  display: flex;
  flex-direction: column;
  align-items: center;
  padding: 45px 0 25px 0;
}

body.light-mode .DRAWimgbox {
  display: flex;
  flex-direction: column;
  align-items: center;
  box-shadow: 0px 10px 30px 10px #7d7d7d80;
  border-radius: 25px;
  width: 95%;
  overflow: hidden;
  position: relative;
}

body.dark-mode .DRAWimgbox {
  display: flex;
  flex-direction: column;
  align-items: center;
  box-shadow: 0px 10px 30px 10px #00000080;
  border-radius: 25px;
  width: 95%;
  overflow: hidden;
  position: relative;
}

.DRAWimgbox_1 {
  /* position: absolute; */
  width: 100%;
  height: 100%;
  object-fit: cover;
}

/* Ã¥Â¤Å¡Ã¥â€ºÂ¾Ã§Â½â€˜Ã¦Â Â¼Ã¦Â Â·Ã¥Â¼Â */
.image-grid {
  display: grid;
  grid-template-columns: repeat(auto-fill, minmax(250px, 1fr));
  gap: 1rem;
  padding: 1rem;
}

.image-container {
  aspect-ratio: 1 / 1;
  position: relative;
  overflow: hidden;
  border-radius: 8px;
  box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
}

.grid-image {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  object-fit: cover;
}

@media (min-width: 768px) {
  .image-grid {
    grid-template-columns: repeat(3, 1fr);
  }
}

.forward_name {
  display: flex;
  font-size: 30px;
  align-items: center;
}

.forward_user_info {
  display: flex;
  font-size: 30px;
  justify-content: space-between;
}

.forward_decoration_card {
  margin: 0 0 0 155px;
}

.forward_avatar-1 {
  width: 142px;
  margin: 0 -145px 0 0;
  margin-top: 50px;
  transform: translateY(-19%) translateX(-130%) scale(1.6);
}

body.light-mode .DYNAMIC_TYPE_LIVE_RCMD {
  background-color: #efefef;
  border-radius: 20px;
  margin-top: 14px;
  padding: 30px 50px 65px 50px;
  width: 100%;
}

body.dark-mode .DYNAMIC_TYPE_LIVE_RCMD {
  background-color: #282828;
  border-radius: 15px;
  margin-top: 14px;
  padding: 30px 50px 65px 50px;
  width: 100%;
}

.LIVE_RCMDuserinfo {
  display: flex;
  align-items: center;
  padding: 25px 0 0 35px;
}

.LIVE_RCMDcover {
  display: flex;
  flex-direction: column;
  align-items: center;
  padding: 45px 0 25px 0;
}

body.light-mode .LIVE_RCMDimgbox {
  display: flex;
  flex-direction: column;
  align-items: center;
  box-shadow: 0px 10px 20px 0px #a5a5a5;
  border-radius: 40px;
  width: 100%;
  aspect-ratio: 16 / 9;
  overflow: hidden;
  position: relative;
}

body.dark-mode .LIVE_RCMDimgbox {
  display: flex;
  flex-direction: column;
  align-items: center;
  box-shadow: 0px 10px 30px 10px #0f0f0f;
  border-radius: 25px;
  width: 100%;
  aspect-ratio: 16 / 9;
  overflow: hidden;
  position: relative;
}


.LIVE_RCMDimgbox_1 {
  position: absolute;
  width: 100%;
  object-fit: cover;
  object-position: center 200%;
}