@charset "UTF-8";
@import '../../../font/bilifont/font.css';

* {
  margin: 0;
  padding: 0;
  box-sizing: border-box;
  -webkit-user-select: none;
  -moz-user-select: none;
  user-select: none;
}

body {
  color: #1e1f20;
  font-family: "HarmonyOSHans-Regular", "bilifont", "PingFang SC", "Noto Sans CJK SC", 'Microsoft YaHei', "Noto Color Emoji", "FZB", Number, sans-serif;
  transform-origin: 0 0;
  width: 1440px;
}

body.light-mode .container {
  background-color: #f4f4f4;
  width: 1440px;
  padding: 20px 15px 10px 15px;
  background-size: contain;
}

body.dark-mode .container {
  background-color: #202021;
  width: 1440px;
  padding: 20px 15px 10px 15px;
  background-size: contain;
}

.head-box {
  border-radius: 15px;
  padding: 10px 20px;
  position: relative;
  color: #fff;
  margin-top: 30px;
}

.head-box .label {
  font-size: 16px;
  text-shadow: 0 0 1px #000, 1px 1px 3px rgba(0, 0, 0, 0.9);
}

.head-box .label span {
  color: #d3bc8e;
  padding: 0 2px;
}

.notice {
  color: #888;
  font-size: 12px;
  text-align: right;
  padding: 12px 5px 5px;
}

.notice-center {
  color: #fff;
  text-align: center;
  margin-bottom: 10px;
  text-shadow: 1px 1px 1px #333;
}

body.light-mode .copyright {
  font-weight: 700;
  font-size: 50px;
  text-align: center;
  color: #b4b4b4;
  position: relative;
  padding-left: 10px;
  margin: 40px 0;
}

body.light-mode .copyright .version {
  padding: 0 10px;
  margin: 0 0 0 5px;
  font-size: 25px;
  color: #666666;
  text-shadow: 0px 0px 20px #00000000;
  background-color: #d7d7d7;
  border-radius: 10px;
  vertical-align: super;
}

body.light-mode .copyright .name {
  color: #666666;
}

body.dark-mode .copyright {
  font-weight: 700;
  font-size: 50px;
  text-align: center;
  color: #666666;
  position: relative;
  padding-left: 10px;
  margin: 40px 0;
}

body.dark-mode .copyright .version {
  padding: 0 10px;
  margin: 0 0 0 5px;
  font-size: 25px;
  color: #d6d6d6;
  text-shadow: 0px 0px 20px #00000000;
  background-color: #666666;
  border-radius: 10px;
  vertical-align: super;
}

body.dark-mode .copyright .name {
  color: #d6d6d6;
}

.copyright .commit_id_old {
  color: #808080;
  /* 与 .version 保持一致的样式，但颜色不同 */
  padding: 0 10px; /* 与 version 一致 */
  margin: 0 0 0 5px; /* 与 version 一致 */
  font-size: 25px; /* 与 version 一致 */
  text-shadow: 0px 0px 20px #00000000; /* 与 version 一致 */
  border-radius: 10px; /* 与 version 一致 */
  vertical-align: super; /* 与 version 一致 */
  /* 根据亮色/暗色模式设置背景色 */
}

/* 为 commit_id_old 和 tip 分别设置亮色和暗色模式下的背景色 */
body.light-mode .copyright .commit_id_old {
  background-color: #e9e9e9; /* 比 version 的背景色稍暗或不同，以作区分 */
  color: #808080;
}

body.dark-mode .copyright .commit_id_old {
  background-color: #505050; /* 比 version 的背景色稍亮或不同，以作区分 */
  color: #a0a0a0;
}

.copyright .tip {
  /* 核心：颜色设为红色 */
  color: #ff0000 !important; /* 使用 !important 确保覆盖其他可能存在的颜色设置 */
  /* 与 .version 保持一致的样式 */
  padding: 0 10px;
  margin: 0 0 0 5px;
  font-size: 25px; /* 与 version 一致 */
  text-shadow: 0px 0px 20px #00000000; /* 与 version 一致 */
  border-radius: 10px; /* 与 version 一致 */
  vertical-align: super; /* 与 version 一致 */
  /* 根据亮色/暗色模式设置背景色，可以与 version 的背景色相同，或者略作区分 */
}

/* 为 .tip 设置亮色和暗色模式下的背景色 */
body.light-mode .copyright .tip {
  background-color: #d7d7d7; /* 与 version 在 light-mode 下的背景色一致 */
}

body.dark-mode .copyright .tip {
  background-color: #666666; /* 与 version 在 dark-mode 下的背景色一致 */
}

/* cont */
.cont {
  border-radius: 20px;
  background: url("../common/cont/card-bg.png") top left repeat-x;
  background-size: auto 100%;
  margin: 5px 15px 5px 10px;
  position: relative;
  box-shadow: 0 0 1px 0 #ccc, 2px 2px 4px 0 rgba(50, 50, 50, 0.8);
  overflow: hidden;
  color: #fff;
  font-size: 10px;
}

.cont>ul.cont-msg {
  display: block;
  padding: 5px 10px;
  background: rgba(0, 0, 0, 0.5);
}

.cont-title {
  background: rgba(0, 0, 0, 0.4);
  box-shadow: 0 0 1px 0 #fff;
  color: #d3bc8e;
  padding: 10px 20px;
  text-align: left;
  border-radius: 10px 10px 0 0;
}

.cont-title span {
  font-size: 12px;
  color: #aaa;
  margin-left: 10px;
  font-weight: 400;
}

.cont-title.border-less {
  background: linear-gradient(rgba(0, 0, 0, 0.5), rgba(0, 0, 0, 0));
  box-shadow: none;
  padding-bottom: 5px;
}

.cont-body {
  padding: 10px 15px;
  font-size: 12px;
  background: rgba(0, 0, 0, 0.5);
  box-shadow: 0 0 1px 0 #fff;
  font-weight: 400;
}

.cont-footer {
  padding: 10px 15px;
  font-size: 12px;
  background: rgba(0, 0, 0, 0.5);
  font-weight: 400;
}

ul.cont-msg,
.cont-footer ul {
  padding-left: 15px;
}

ul.cont-msg li,
.cont-footer ul li {
  margin: 5px 0;
  margin-left: 15px;
}

ul.cont-msg li strong,
.cont-footer ul li strong {
  font-weight: 400;
  margin: 0 2px;
  color: #d3bc8e;
}

.cont-table {
  display: table;
  width: 100%;
}

.cont-table .tr {
  display: table-row;
}

.cont-table .tr:nth-child(even) {
  background: rgba(0, 0, 0, 0.4);
}

.cont-table .tr:nth-child(odd) {
  background: rgba(50, 50, 50, 0.4);
}

.cont-table .tr>div.value-full {
  display: table;
  width: 200%;
}

.cont-table .tr>div.value-none {
  box-shadow: none;
}

.cont-table .thead {
  text-align: center;
}

.cont-table .tr>div,
.cont-table .tr>td {
  display: table-cell;
  box-shadow: 0 0 1px 0 #fff;
}

.cont-table .thead>div,
.cont-table .thead>td {
  color: #d3bc8e;
  background: rgba(0, 0, 0, 0.4);
  line-height: 40px;
  height: 40px;
}

.cont-table .title,
.cont-table .th {
  color: #d3bc8e;
  padding-right: 15px;
  text-align: right;
  background: rgba(0, 0, 0, 0.4);
  min-width: 100px;
  vertical-align: middle;
}

.logo {
  font-size: 18px;
  text-align: center;
  color: #fff;
  margin: 20px 0 10px 0;
}

/*  */
.cons {
  display: inline-block;
  vertical-align: middle;
  padding: 0 5px;
  border-radius: 4px;
}

.cons-0 {
  background: #666;
  color: #fff;
}

.cons-n0 {
  background: #404949;
  color: #fff;
}

.cons-1 {
  background: #5cbac2;
  color: #fff;
}

.cons-2 {
  background: #339d61;
  color: #fff;
}

.cons-3 {
  background: #3e95b9;
  color: #fff;
}

.cons-4 {
  background: #3955b7;
  color: #fff;
}

.cons-5 {
  background: rgba(83, 27, 169, 0.8117647059);
  color: #fff;
}

.cons-6 {
  background: #ff5722;
  color: #fff;
}

.cons2-0 {
  border-radius: 4px;
  background: #666;
  color: #fff;
}

.cons2-1 {
  border-radius: 4px;
  background: #71b1b7;
  color: #fff;
}

.cons2-2 {
  border-radius: 4px;
  background: #369961;
  color: #fff;
}

.cons2-3 {
  border-radius: 4px;
  background: #4596b9;
  color: #fff;
}

.cons2-4 {
  border-radius: 4px;
  background: #4560b9;
  color: #fff;
}

.cons2-5 {
  border-radius: 4px;
  background: rgba(83, 27, 169, 0.8117647059);
  color: #fff;
}

.cons2-6 {
  border-radius: 4px;
  background: #ff5722;
  color: #fff;
}

.logo {
  font-size: 18px;
  text-align: center;
  color: #fff;
  margin: 20px 0 10px 0;
}

/* item-icon */
.item-icon {
  width: 100%;
  height: 100%;
  border-radius: 4px;
  position: relative;
  overflow: hidden;
}

.item-icon .img {
  width: 100%;
  height: 100%;
  display: block;
  background-size: contain;
  background-position: center;
  background-repeat: no-repeat;
}

.item-icon.artis .img {
  width: 84%;
  height: 84%;
  margin: 8%;
}

.item-list {
  display: flex;
}

.item-list .item-card {
  width: 70px;
  background: #e7e5d9;
}

.item-list .item-icon {
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 12px;
  height: initial;
}

.item-list .item-title {
  color: #222;
  font-size: 13px;
  text-align: center;
  padding: 2px;
  white-space: nowrap;
  overflow: hidden;
}

.item-list .item-badge {
  position: absolute;
  display: block;
  left: 0;
  top: 0;
  background: rgba(0, 0, 0, 0.6);
  font-size: 12px;
  color: #fff;
  padding: 4px 5px 3px;
  border-radius: 0 0 6px 0;
}

/*# sourceMappingURL=common.css.map */
